@@ -1,12 +1,12 @@
 package Perinci;
 
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 1;
 # ABSTRACT: Collection of Perl modules for Rinci and Riap
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -15,7 +15,7 @@ Perinci - Collection of Perl modules for Rinci and Riap
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 DESCRIPTION
 
@@ -29,14 +29,14 @@ incremental releases. These tools include:
 
 L<Perinci::Sub::Wrapper> is the subroutine wrapper which implements/enforces
 many of the metadata properties, like argument validation (using information in
-C<args>) as well as offers features like convert argument passing style,
-automatically envelope function result, etc.
+C<args>) as well as offers features like assign default values, convert argument
+passing style, automatically envelope function result, etc.
 
 It is extensible so you can implement wrapper for your properties too.
 
 =item * Riap clients and servers (Perinci::Access::*)
 
-L<Perinci::Access::InProcess> is a client/server (well, neither really, since
+L<Perinci::Access::Perl> is a client/server (well, neither really, since
 everything is in-process) to access Perl modules/functions using the Riap
 protocol. It is basically a way to call your modules/functions using URI syntax;
 it also dictates a bit on how you should write your functions and where to put
@@ -72,11 +72,11 @@ These are convenient tools to generate common/generic function and/or metadata.
 For example, L<Perinci::Sub::Gen::AccessTable> can generate accessor function +
 metadata for table data.
 
-See CPAN for more Perinci::Sub::Gen::* modules.
+See CPAN for more C<Perinci::Sub::Gen::*> modules.
 
 =item * Others
 
-Samples: L<Perinci::Use>, L<Perinci::Exporter>.
+Samples: L<Perinci::Use>, L<Perinci::Exporter>, L<Test::Rinci>.
 
 See CPAN for more Perinci::* modules.
 
@@ -84,25 +84,6 @@ See CPAN for more Perinci::* modules.
 
 To get started, read L<Perinci::Manual::Tutorial>.
 
-=head1 STATUS
-
-Most modules have been implemented. It is safe to start putting metadata to your
-code. However, some have not:
-
-=over 4
-
-=item * Argument validation
-
-L<Perinci::Sub::Wrapper> still does not generate code to validate function
-arguments. This is because the L<Sah> schema is still somewhat in flux and
-largely unimplemented.
-
-I usually do some manual and minimal argument validation manually in the
-function body. They can be removed once the wrapper generates validation code,
-or left as-is (sometimes the function is used unwrapped).
-
-=back
-
 =head1 FAQ
 
 =head2 What does Perinci mean?
@@ -120,10 +101,9 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
